import { Injectable } from '@nestjs/common';
import { TrpcService } from '@server/trpc/trpc.service';
import { BookService } from './book.service';
import { Prisma } from '@nice/common';
import { z, ZodType } from 'zod';

const BookUncheckedCreateInputSchema: ZodType<Prisma.BookUncheckedCreateInput> =
  z.any();
const BookWhereInputSchema: ZodType<Prisma.BookWhereInput> = z.any();
const BookSelectSchema: ZodType<Prisma.BookSelect> = z.any();
const BookUpdateArgsSchema: ZodType<Prisma.BookUpdateArgs> = z.any();
const BookFindFirstArgsSchema: ZodType<Prisma.BookFindFirstArgs> = z.any();
const BookFindManyArgsSchema: ZodType<Prisma.BookFindManyArgs> = z.any();

@Injectable()
export class BookRouter {
  constructor(
    private readonly trpc: TrpcService,
    private readonly bookService: BookService,
  ) {}

  router = this.trpc.router({
    create: this.trpc.procedure
      .input(BookUncheckedCreateInputSchema)
      .mutation(async ({ input }) => {
        return this.bookService.create({ data: input });
      }),

    update: this.trpc.procedure
      .input(BookUpdateArgsSchema)
      .mutation(async ({ input }) => {
        return this.bookService.update(input);
      }),

    findMany: this.trpc.procedure
      .input(BookFindManyArgsSchema)
      .query(async ({ input }) => {
        return this.bookService.findMany(input);
      }),

    softDeleteByIds: this.trpc.procedure
      .input(z.object({ ids: z.array(z.string()) }))
      .mutation(async ({ input }) => {
        return this.bookService.softDeleteByIds(input.ids);
      }),

    findFirst: this.trpc.procedure
      .input(BookFindFirstArgsSchema)
      .query(async ({ input }) => {
        return this.bookService.findFirst(input);
      }),
  });
}
