import { Injectable } from '@nestjs/common';
import { TrpcService } from '@server/trpc/trpc.service';
import { BorrowRecordService } from './borrowRecord.service';
import { Prisma } from '@nice/common';
import { z, ZodType } from 'zod';

const BorrowRecordUncheckedCreateInputSchema: ZodType<Prisma.BorrowRecordUncheckedCreateInput> =
  z.any();
const BorrowRecordWhereInputSchema: ZodType<Prisma.BorrowRecordWhereInput> =
  z.any();
const BorrowRecordSelectSchema: ZodType<Prisma.BorrowRecordSelect> = z.any();
const BorrowRecordUpdateArgsSchema: ZodType<Prisma.BorrowRecordUpdateArgs> =
  z.any();
const BorrowRecordFindFirstArgsSchema: ZodType<Prisma.BorrowRecordFindFirstArgs> =
  z.any();
const BorrowRecordFindManyArgsSchema: ZodType<Prisma.BorrowRecordFindManyArgs> =
  z.any();

@Injectable()
export class BorrowRecordRouter {
  constructor(
    private readonly trpc: TrpcService,
    private readonly borrowRecordService: BorrowRecordService,
  ) {}

  router = this.trpc.router({
    create: this.trpc.procedure
      .input(BorrowRecordUncheckedCreateInputSchema)
      .mutation(async ({ input }) => {
        return this.borrowRecordService.create({ data: input });
      }),

    update: this.trpc.procedure
      .input(BorrowRecordUpdateArgsSchema)
      .mutation(async ({ input }) => {
        return this.borrowRecordService.update(input);
      }),

    findMany: this.trpc.procedure
      .input(BorrowRecordFindManyArgsSchema)
      .query(async ({ input }) => {
        return this.borrowRecordService.findMany(input);
      }),

    softDeleteByIds: this.trpc.procedure
      .input(z.object({ ids: z.array(z.string()) }))
      .mutation(async ({ input }) => {
        return this.borrowRecordService.softDeleteByIds(input.ids);
      }),

    findFirst: this.trpc.procedure
      .input(BorrowRecordFindFirstArgsSchema)
      .query(async ({ input }) => {
        return this.borrowRecordService.findFirst(input);
      }),
  });
}
