import { Injectable } from '@nestjs/common';
import { BaseService } from '../base/base.service';
import { db, ObjectType, Prisma, UserProfile } from '@nice/common';
import EventBus, { CrudOperation } from '@server/utils/event-bus';
import { DefaultArgs } from '@prisma/client/runtime/library';

@Injectable()
export class CommentService extends BaseService<Prisma.CommentDelegate> {
  constructor() {
    super(db, ObjectType.COMMENT, false);
  }
  async create(args: Prisma.CommentCreateArgs) {
    const result = await super.create(args);
    this.emitDataChanged(CrudOperation.CREATED, result);
    return result;
  }

  async update(args: Prisma.CommentUpdateArgs) {
    const result = await super.update(args);
    this.emitDataChanged(CrudOperation.UPDATED, result);
    return result;
  }

  async findMany(args: Prisma.CommentFindManyArgs) {
    const result = await super.findMany(args);
    return result;
  }
  async findFirst(args: Prisma.CommentFindFirstArgs) {
    const result = await super.findFirst(args);
    return result;
  }
  async softDeleteByIds(ids: string[]) {
    const result = await super.softDeleteByIds(ids);
    this.emitDataChanged(CrudOperation.DELETED, result);
    return result;
  }

  private emitDataChanged(operation: CrudOperation, data: any) {
    EventBus.emit('dataChanged', {
      type: ObjectType.COMMENT,
      operation,
      data,
    });
  }
}
