import { Injectable } from '@nestjs/common';
import { TrpcService } from '@server/trpc/trpc.service';
import { LibraryService } from './library.service';
import { Prisma } from '@nice/common';
import { z, ZodType } from 'zod';

const LibraryUncheckedCreateInputSchema: ZodType<Prisma.LibraryUncheckedCreateInput> =
  z.any();
const LibraryWhereInputSchema: ZodType<Prisma.LibraryWhereInput> = z.any();
const LibrarySelectSchema: ZodType<Prisma.LibrarySelect> = z.any();
const LibraryUpdateArgsSchema: ZodType<Prisma.LibraryUpdateArgs> = z.any();
const LibraryFindFirstArgsSchema: ZodType<Prisma.LibraryFindFirstArgs> =
  z.any();
const LibraryFindManyArgsSchema: ZodType<Prisma.LibraryFindManyArgs> = z.any();

@Injectable()
export class LibraryRouter {
  constructor(
    private readonly trpc: TrpcService,
    private readonly libraryService: LibraryService,
  ) {}

  router = this.trpc.router({
    create: this.trpc.procedure
      .input(LibraryUncheckedCreateInputSchema)
      .mutation(async ({ input }) => {
        return this.libraryService.create({ data: input });
      }),

    update: this.trpc.procedure
      .input(LibraryUpdateArgsSchema)
      .mutation(async ({ input }) => {
        return this.libraryService.update(input);
      }),

    findMany: this.trpc.procedure
      .input(LibraryFindManyArgsSchema)
      .query(async ({ input }) => {
        return this.libraryService.findMany(input);
      }),

    softDeleteByIds: this.trpc.procedure
      .input(z.object({ ids: z.array(z.string()) }))
      .mutation(async ({ input }) => {
        return this.libraryService.softDeleteByIds(input.ids);
      }),

    findFirst: this.trpc.procedure
      .input(LibraryFindFirstArgsSchema)
      .query(async ({ input }) => {
        return this.libraryService.findFirst(input);
      }),
  });
}
