import { Injectable } from '@nestjs/common';
import { BaseService } from '../base/base.service';
import { db, ObjectType, Prisma } from '@nice/common';
import EventBus, { CrudOperation } from '@server/utils/event-bus';

@Injectable()
export class LibraryService extends BaseService<Prisma.LibraryDelegate> {
  constructor() {
    super(db, ObjectType.LIBRARY, false);
  }

  async create(args: Prisma.LibraryCreateArgs) {
    const result = await super.create(args);
    this.emitDataChanged(CrudOperation.CREATED, result);
    return result;
  }

  async update(args: Prisma.LibraryUpdateArgs) {
    const result = await super.update(args);
    this.emitDataChanged(CrudOperation.UPDATED, result);
    return result;
  }

  async findMany(args: Prisma.LibraryFindManyArgs) {
    const result = await super.findMany(args);
    return result;
  }

  async findFirst(args: Prisma.LibraryFindFirstArgs) {
    const result = await super.findFirst(args);
    return result;
  }

  async softDeleteByIds(ids: string[]) {
    const result = await super.softDeleteByIds(ids);
    this.emitDataChanged(CrudOperation.DELETED, result);
    return result;
  }

  private emitDataChanged(operation: CrudOperation, data: any) {
    EventBus.emit('dataChanged', {
      type: ObjectType.LIBRARY,
      operation,
      data,
    });
  }
}
