import { Injectable } from '@nestjs/common';
import { TrpcService } from '@server/trpc/trpc.service';
import { ReaderService } from './reader.service';
import { Prisma } from '@nice/common';
import { z, ZodType } from 'zod';

const ReaderUncheckedCreateInputSchema: ZodType<Prisma.ReaderUncheckedCreateInput> =
  z.any();
const ReaderWhereInputSchema: ZodType<Prisma.ReaderWhereInput> = z.any();
const ReaderSelectSchema: ZodType<Prisma.ReaderSelect> = z.any();
const ReaderUpdateArgsSchema: ZodType<Prisma.ReaderUpdateArgs> = z.any();
const ReaderFindFirstArgsSchema: ZodType<Prisma.ReaderFindFirstArgs> = z.any();
const ReaderFindManyArgsSchema: ZodType<Prisma.ReaderFindManyArgs> = z.any();

@Injectable()
export class ReaderRouter {
  constructor(
    private readonly trpc: TrpcService,
    private readonly readerService: ReaderService,
    // private readonly termService: TermService, // 添加 TermService
  ) {}

  router = this.trpc.router({
    create: this.trpc.procedure
      .input(ReaderUncheckedCreateInputSchema)
      .mutation(async ({ input }) => {
        console.log(input);
        return this.readerService.create({ data: input });
      }),
    update: this.trpc.procedure
      .input(ReaderUpdateArgsSchema)
      .mutation(async ({ input }) => {
        return this.readerService.update(input);
      }),
    findMany: this.trpc.procedure
      .input(ReaderFindManyArgsSchema)
      .query(async ({ input }) => {
        return this.readerService.findMany(input);
      }),
    softDeleteByIds: this.trpc.procedure
      .input(z.object({ ids: z.array(z.string()) }))
      .mutation(async ({ input }) => {
        return this.readerService.softDeleteByIds(input.ids);
      }),
    findFirst: this.trpc.procedure
      .input(ReaderFindFirstArgsSchema)
      .query(async ({ input }) => {
        return this.readerService.findFirst(input);
      }),
    // 获取读者分类
    getReaderTypes: this.trpc.procedure.query(async () => {
      return this.readerService.getReaderTypes();
    }),

    // 为读者分配分类
    assignReaderType: this.trpc.procedure
      .input(
        z.object({
          readerId: z.string(),
          termId: z.string(),
        }),
      )
      .mutation(async ({ input }) => {
        return this.readerService.assignReaderType(
          input.readerId,
          input.termId,
        );
      }),

    // 移除读者分类
    removeReaderType: this.trpc.procedure
      .input(
        z.object({
          readerId: z.string(),
          termId: z.string(),
        }),
      )
      .mutation(async ({ input }) => {
        return this.readerService.removeReaderType(
          input.readerId,
          input.termId,
        );
      }),
  });
}
