import { Injectable } from '@nestjs/common';
import { TrpcService } from '@server/trpc/trpc.service';
import { UserService } from './user.service';
import { Prisma } from '@nice/common';
import { z, ZodType } from 'zod';

const UserUncheckedCreateInputSchema: ZodType<Prisma.UserUncheckedCreateInput> =
  z.any();
const UserWhereInputSchema: ZodType<Prisma.UserWhereInput> = z.any();
const UserSelectSchema: ZodType<Prisma.UserSelect> = z.any();
const UserUpdateArgsSchema: ZodType<Prisma.UserUpdateArgs> = z.any();
const UserFindFirstArgsSchema: ZodType<Prisma.UserFindFirstArgs> = z.any();
const UserFindManyArgsSchema: ZodType<Prisma.UserFindManyArgs> = z.any();

@Injectable()
export class UserRouter {
  constructor(
    private readonly trpc: TrpcService,
    private readonly userService: UserService,
  ) {}

  router = this.trpc.router({
    create: this.trpc.procedure
      .input(UserUncheckedCreateInputSchema)
      .mutation(async ({ input }) => {
        return this.userService.create({ data: input });
      }),

    update: this.trpc.procedure
      .input(UserUpdateArgsSchema)
      .mutation(async ({ input }) => {
        return this.userService.update(input);
      }),

    findMany: this.trpc.procedure
      .input(UserFindManyArgsSchema)
      .query(async ({ input }) => {
        return this.userService.findMany(input);
      }),

    softDeleteByIds: this.trpc.procedure
      .input(z.object({ ids: z.array(z.string()) }))
      .mutation(async ({ input }) => {
        return this.userService.softDeleteByIds(input.ids);
      }),

    findFirst: this.trpc.procedure
      .input(UserFindFirstArgsSchema)
      .query(async ({ input }) => {
        return this.userService.findFirst(input);
      }),
  });
}
