import { Injectable } from '@nestjs/common';
import { BaseService } from '../base/base.service';
import { db, ObjectType, Prisma } from '@nice/common';
import EventBus, { CrudOperation } from '@server/utils/event-bus';

@Injectable()
export class UserService extends BaseService<Prisma.UserDelegate> {
  constructor() {
    super(db, ObjectType.USER, false);
  }

  async create(args: Prisma.UserCreateArgs) {
    const result = await super.create(args);
    this.emitDataChanged(CrudOperation.CREATED, result);
    return result;
  }

  async update(args: Prisma.UserUpdateArgs) {
    const result = await super.update(args);
    this.emitDataChanged(CrudOperation.UPDATED, result);
    return result;
  }

  async findMany(args: Prisma.UserFindManyArgs) {
    const result = await super.findMany(args);
    return result;
  }

  async findFirst(args: Prisma.UserFindFirstArgs) {
    const result = await super.findFirst(args);
    return result;
  }

  async softDeleteByIds(ids: string[]) {
    const result = await super.softDeleteByIds(ids);
    this.emitDataChanged(CrudOperation.DELETED, result);
    return result;
  }

  private emitDataChanged(operation: CrudOperation, data: any) {
    EventBus.emit('dataChanged', {
      type: ObjectType.USER,
      operation,
      data,
    });
  }
}
