import {
  db,
  getRandomElement,
  getRandomIntInRange,
  getRandomTimeInterval,
  PostType,
} from '@nice/common';
import dayjs from 'dayjs';
export interface DevDataCounts {
  deptCount: number;
  trainContentCount: number;
  staffCount: number;
  termCount: number;
  courseCount: number;
}

//查询数据库并返回各种实体的当前计数
export async function getCounts(): Promise<DevDataCounts> {
  const counts = {
    deptCount: await db.department.count(),
    trainContentCount: await db.trainContent.count(),
    staffCount: await db.staff.count(),
    termCount: await db.term.count(),
    courseCount: await db.post.count({
      where: {
        type: PostType.COURSE,
      },
    }),
  };
  return counts;
}

//将字符串的首字母大写
export function capitalizeFirstLetter(string: string) {
  return string.charAt(0).toUpperCase() + string.slice(1);
}

//这个函数生成指定数量的随机图片链接
export function getRandomImageLinks(count: number = 5): string[] {
  const baseUrl = 'https://picsum.photos/200/300?random=';
  const imageLinks: string[] = [];

  for (let i = 0; i < count; i++) {
    // 生成随机数以确保每个链接都是唯一的
    const randomId = Math.floor(Math.random() * 1000);
    imageLinks.push(`${baseUrl}${randomId}`);
  }

  return imageLinks;
}
