import { Modal, Form, Input, Select } from 'antd';
import { Book, Library } from './types';
import React, { useEffect } from 'react';
import TermSelect from '@web/src/components/models/term/term-select';
import { api } from '@nice/client';

interface BookModalProps {
    open: boolean;
    loading?: boolean;
    editingBook?: Book;
    libraryList?: Library[];
    onOk: (values: any) => void;
    onCancel: () => void;
}

export const BookModal: React.FC<BookModalProps> = ({
    open,
    loading,
    editingBook,
    libraryList,
    onOk,
    onCancel,
}) => {
    const [form] = Form.useForm();

    // 查询图书分类的taxonomy
    const { data: taxonomies } = api.taxonomy.getAll.useQuery({
        
        // type: 'book'
    });

     // 当编辑图书时，设置初始值
     //bug，需要再新增时初始化表单
     useEffect(() => {
        if (editingBook && open) {
            form.setFieldsValue({
                ...editingBook,
                termIds: editingBook.terms?.map(term => term.id) || []
            });
        } else if (!editingBook && open) {
            form.resetFields();
        }
    }, [editingBook, open, form]);

    // 找到图书分类的taxonomy
    const bookTaxonomy = taxonomies?.find(tax => tax.objectType.includes('book'));

    return (
        <Modal
            title={editingBook ? '编辑图书' : '新增图书'}
            open={open}
            onOk={() => form.submit()}
            onCancel={onCancel}
            confirmLoading={loading}
        >
            <Form
                form={form}
                layout="vertical"
                initialValues={editingBook}
                onFinish={(values) => {
                    // 确保数据格式正确
                    const formData = {
                        bookName: values.bookName,
                        isbn: values.isbn,
                        author: values.author,
                        termIds: values.termIds, // 添加图书分类ID
                        libraryId: values.libraryId,
                    };
                    onOk(formData);
                }}
            >
                <Form.Item
                    name="bookName"
                    label="书名"
                    rules={[{ required: true, message: '请输入书名' }]}
                >
                    <Input />
                </Form.Item>

                <Form.Item
                    name="isbn"
                    label="图书编码"
                    rules={[{ required: true, message: '请输入图书编码' }]}
                >
                    <Input />
                </Form.Item>

                <Form.Item
                    name="author"
                    label="作者"
                    rules={[{ required: true, message: '请输入作者' }]}
                >
                    <Input />
                </Form.Item>

                {bookTaxonomy && (
                    <Form.Item
                        name="termIds"
                        label="图书分类"
                    >
                        <TermSelect
                            multiple
                            placeholder="请选择图书分类"
                            taxonomyId={bookTaxonomy.id}
                        />
                    </Form.Item>
                )}


                <Form.Item
                    name="libraryId"
                    label="所属图书馆"
                    rules={[{ required: true, message: '请选择所属图书馆' }]}
                >
                    <Select
                        allowClear
                        placeholder="请选择图书馆"
                    >
                        {libraryList?.map(library => (
                            <Select.Option key={library.id} value={library.id}>
                                {library.name}  {/* 使用数据库中的 name 字段 */}
                            </Select.Option>
                        ))}
                    </Select>
                </Form.Item>
            </Form>
        </Modal>
    );
};