import { Table, Space, Button, Popconfirm, Tag } from 'antd';
import type { ColumnsType } from 'antd/es/table';
import { Book } from './types';

import React from 'react';
interface BookTableProps {
  data: Book[];
  loading?: boolean;
  onEdit: (record: Book) => void;
  onDelete: (ids: string[]) => void;
}

export const BookTable: React.FC<BookTableProps> = ({
  data,
  loading,
  onEdit,
  onDelete,
}) => {
  const columns: ColumnsType<Book> = [
    {
      title: '图书名称',
      dataIndex: 'bookName',
      key: 'bookName',
    },
    {
      title: '图书编码',
      dataIndex: 'isbn',
      key: 'isbn',
    },
    {
      title: '作者',
      dataIndex: 'author',
      key: 'author',
    },
    {
      title: '图书分类',
      key: 'terms',
      render: (_, record) => (
        <>
          {record.terms?.map(term => (
            <Tag color="blue" key={term.id}>
              {term.name}
            </Tag>
          ))}
        </>
      ),
    },
    {
      title: '所属图书馆',
      dataIndex: ['library', 'name'],
      key: 'libraryName',
    },
    {
      title: '创建时间',
      dataIndex: 'createdAt',
      key: 'createdAt',
      render: (date: string) => new Date(date).toLocaleString('zh-CN'),
    },
    {
      title: '操作',
      key: 'action',
      render: (_, record) => (
        <Space size="middle">
          <Button type="link" onClick={() => onEdit(record)}>
            编辑
          </Button>
          <Popconfirm
            title="确定要删除吗？"
            onConfirm={() => onDelete([record.id])}
          >
            <Button type="link" danger>
              删除
            </Button>
          </Popconfirm>
        </Space>
      ),
    },
  ];

  return (
    <Table
      columns={columns}
      dataSource={data}
      loading={loading}
      rowKey="id"
    />
  );
};