import { Button, Space, Table, Tag, Popconfirm } from 'antd';
import type { ColumnsType } from 'antd/es/table';
import { BorrowRecord } from './types';
import React from 'react';

interface BorrowRecordTableProps {
    data: BorrowRecord[];
    loading?: boolean;
    onEdit: (record: BorrowRecord) => void;
    onDelete: (ids: string[]) => void;
}

export const BorrowRecordTable: React.FC<BorrowRecordTableProps> = ({
    data,
    loading,
    onEdit,
    onDelete,
}) => {
    console.log(data);
    
    const columns: ColumnsType<BorrowRecord> = [
        {
            title: '图书名称',
            dataIndex: ['book', 'bookName'],
            key: 'bookName',
        },
        {
            title: '图书ISBN',
            dataIndex: ['book', 'isbn'],
            key: 'isbn',
        },
        {
            title: '借阅人',
            dataIndex: ['reader', 'name'],
            key: 'readerName',
        },
        {
            title: '所属图书馆',
            dataIndex: ['library', 'name'],
            key: 'libraryName',
        },
        {
            title: '借出时间',
            dataIndex: 'giveTime',
            key: 'giveTime',
            render: (date: string) => new Date(date).toLocaleString('zh-CN'),
        },
        {
            title: '应还时间',
            dataIndex: 'backTime',
            key: 'backTime',
            render: (date: string) => new Date(date).toLocaleString('zh-CN'),
        },
        {
            title: '实际归还时间',
            dataIndex: 'isbackTime',
            key: 'isbackTime',
            render: (date: string) => {
                const isbackDate = new Date(date);
                const backDate = new Date(0); // 1970年1月1日
                return isbackDate > backDate ?
                    isbackDate.toLocaleString('zh-CN') :
                    <Tag color="red">未归还</Tag>;
            },
        },
        {
            title: '操作',
            key: 'action',
            render: (_, record) => (
                <Space size="middle">
                    <Button type="link" onClick={() => onEdit(record)}>
                        编辑
                    </Button>
                    <Popconfirm
                        title="确定要删除吗？"
                        onConfirm={() => onDelete([record.id])}
                    >
                        <Button type="link" danger>
                            删除
                        </Button>
                    </Popconfirm>
                </Space>
            ),
        },
    ];

    return (
        <Table
            columns={columns}
            dataSource={data}
            loading={loading}
            rowKey="id"
        />
    );
};