import { Button, Input, Space, Select } from 'antd';
import { SearchOutlined, PlusOutlined } from '@ant-design/icons';
import React, { useState } from 'react';
import { api } from '@nice/client';

interface SearchBarProps {
  searchText: string;
  onSearchTextChange: (text: string) => void;
  onSearch: () => void;
  onAdd: () => void;
  libraryId: string;
  onLibraryChange: (libraryId: string) => void;
}

export const SearchBar: React.FC<SearchBarProps> = ({
  searchText,
  onSearchTextChange,
  onSearch,
  onAdd,
  libraryId,
  onLibraryChange
}) => {
  // 查询所有图书馆
  const { data: libraryList } = api.library.findMany.useQuery({
    where: { deletedAt: null },
  });

  return (
    <div className="mb-4 flex justify-between">
      <Space>
        <Input
          placeholder="搜索图书或读者信息"
          value={searchText}
          onChange={(e) => onSearchTextChange(e.target.value)}
          onPressEnter={onSearch}
          prefix={<SearchOutlined />}
          style={{ width: 200 }}
        />
        <Select
          placeholder="选择图书馆"
          value={libraryId || undefined}
          onChange={onLibraryChange}
          allowClear
          style={{ width: 180 }}
        >
          {libraryList?.map(library => (
            <Select.Option key={library.id} value={library.id}>
              {library.name}
            </Select.Option>
          ))}
        </Select>
        <Button type="primary" onClick={onSearch}>搜索</Button>
      </Space>
      <Button type="primary" icon={<PlusOutlined />} onClick={onAdd}>
        添加借阅记录
      </Button>
    </div>
  );
};