import { Button, Input, Space, Select, Radio } from 'antd';
import { SearchOutlined, PlusOutlined } from '@ant-design/icons';
import React, { useState } from 'react';
import { api } from '@nice/client';

interface SearchBarProps {
  searchText: string;
  onSearchTextChange: (text: string) => void;
  onSearch: () => void;
  onAdd: () => void;
  libraryId: string;
  onLibraryChange: (libraryId: string) => void;
  commentType: 'all' | 'book' | 'library';
  onCommentTypeChange: (type: 'all' | 'book' | 'library') => void;
}

export const SearchBar: React.FC<SearchBarProps> = ({
  searchText,
  onSearchTextChange,
  onSearch,
  onAdd,
  libraryId,
  onLibraryChange,
  commentType,
  onCommentTypeChange
}) => {
  // 查询所有图书馆
  const { data: libraryList } = api.library.findMany.useQuery({
    where: { deletedAt: null },
  });

  return (
    <div className="mb-4 flex flex-wrap justify-between items-center">
      <div className="flex flex-wrap items-center gap-2 mb-2 sm:mb-0">
        <Input
          placeholder="搜索评论内容或评论人"
          value={searchText}
          onChange={(e) => onSearchTextChange(e.target.value)}
          onPressEnter={onSearch}
          prefix={<SearchOutlined />}
          style={{ width: 200 }}
        />
        <Select
          placeholder="选择图书馆"
          value={libraryId || undefined}
          onChange={onLibraryChange}
          allowClear
          style={{ width: 180 }}
        >
          {libraryList?.map(library => (
            <Select.Option key={library.id} value={library.id}>
              {library.name}
            </Select.Option>
          ))}
        </Select>
        <Radio.Group
          value={commentType}
          onChange={(e) => onCommentTypeChange(e.target.value)}
          optionType="button"
          buttonStyle="solid"
        >
          <Radio.Button value="all">全部评论</Radio.Button>
          <Radio.Button value="book">图书评论</Radio.Button>
          <Radio.Button value="library">图书馆评论</Radio.Button>
        </Radio.Group>
        <Button type="primary" onClick={onSearch}>搜索</Button>
      </div>
      <Button type="primary" icon={<PlusOutlined />} onClick={onAdd}>
        添加评论
      </Button>
    </div>
  );
};