import { Modal, Form, Input, Select, DatePicker } from 'antd';
import { Game, Club } from './types';
import React, { useEffect } from 'react';
import dayjs from 'dayjs';

interface GameModalProps {
    open: boolean;
    loading?: boolean;
    editingGame?: Game;
    clubList?: Club[];
    onOk: (values: any) => void;
    onCancel: () => void;
}

export const GameModal: React.FC<GameModalProps> = ({
    open,
    loading,
    editingGame,
    clubList,
    onOk,
    onCancel,
}) => {
    const [form] = Form.useForm();

    useEffect(() => {
        if (editingGame) {
            form.setFieldsValue({
                ...editingGame,
                startTime: editingGame.startTime ? dayjs(editingGame.startTime) : null,
                clubIds: editingGame.clubs?.map(club => club.id) || [],
            });
        } else {
            form.resetFields();
        }
    }, [editingGame, open, form]);

    return (
        <Modal
            title={editingGame ? '编辑比赛' : '新增比赛'}
            open={open}
            onOk={() => form.submit()}
            onCancel={onCancel}
            confirmLoading={loading}
        >
            <Form
                form={form}
                layout="vertical"
                onFinish={(values) => {
                    const formData = {
                        name: values.name,
                        startTime: values.startTime ? values.startTime.toISOString() : null,
                        clubIds: values.clubIds || [],
                    };
                    onOk(formData);
                }}
            >
                <Form.Item
                    name="name"
                    label="比赛名称"
                    rules={[{ required: true, message: '请输入比赛名称' }]}
                >
                    <Input />
                </Form.Item>

                <Form.Item
                    name="startTime"
                    label="比赛开始时间"
                    rules={[{ required: true, message: '请选择比赛开始时间' }]}
                >
                    <DatePicker showTime format="YYYY-MM-DD HH:mm:ss" style={{ width: '100%' }} />
                </Form.Item>

                <Form.Item
                    name="clubIds"
                    label="参与俱乐部"
                    rules={[{ required: true, message: '请选择参与俱乐部', type: 'array' }]}
                >
                    <Select
                        mode="multiple"
                        allowClear
                        placeholder="请选择俱乐部"
                    >
                        {clubList?.map(club => (
                            <Select.Option key={club.id} value={club.id}>
                                {club.name}
                            </Select.Option>
                        ))}
                    </Select>
                </Form.Item>
            </Form>
        </Modal>
    );
};