import { Table, Space, Button, Popconfirm } from 'antd';
import type { ColumnsType } from 'antd/es/table';
import { Game, Sortie } from './types';
import React from 'react';

interface GameTableProps {
  data: Game[];
  loading?: boolean;
  onEdit: (record: Game) => void;
  onDelete: (ids: string[]) => void;
}

export const GameTable: React.FC<GameTableProps> = ({
  data,
  loading,
  onEdit,
  onDelete,
}) => {
  // 主表格列定义
  const columns: ColumnsType<Game> = [
    {
      title: '比赛名称',
      dataIndex: 'name',
      key: 'name',
    },
    {
      title: '比赛开始时间',
      dataIndex: 'startTime',
      key: 'startTime',
      render: (date: string) => new Date(date).toLocaleString('zh-CN'),
    },
    {
      title: '参与俱乐部',
      dataIndex: 'clubs',
      key: 'clubs',
      render: (clubs: any[]) => clubs.map(club => club.name).join(', '),
    },
    {
      title: '操作',
      key: 'action',
      render: (_, record) => (
        <Space size="middle">
          <Button type="link" onClick={() => onEdit(record)}>
            编辑
          </Button>
          <Popconfirm
            title="确定要删除吗？"
            onConfirm={() => onDelete([record.id])}
          >
            <Button type="link" danger>
              删除
            </Button>
          </Popconfirm>
        </Space>
      ),
    },
  ];

  // 子表格列定义（车次信息）
  const expandedRowRender = (record: Game) => {
    const sortieColumns: ColumnsType<Sortie> = [
      {
        title: '驾驶员',
        dataIndex: ['driver', 'name'],
        key: 'driverName',
      },
      {
        title: '车辆',
        dataIndex: ['car', 'name'],
        key: 'carName',
      },
      {
        title: '总时间',
        dataIndex: 'totalTime',
        key: 'totalTime',
        render: (time: number) => `${time.toFixed(2)}秒`,
      },
      {
        title: '得分',
        dataIndex: 'score',
        key: 'score',
        render: (score: number) => score.toFixed(2),
      },
      {
        title: '创建时间',
        dataIndex: 'createdAt',
        key: 'createdAt',
        render: (date: string) => new Date(date).toLocaleString('zh-CN'),
      },
    ];

    return (
      <Table
        columns={sortieColumns}
        dataSource={record.sorties}
        pagination={false}
        rowKey="id"
      />
    );
  };

  return (
    <Table
      columns={columns}
      dataSource={data}
      loading={loading}
      rowKey="id"
      expandable={{
        expandedRowRender,
        defaultExpandAllRows: false,
      }}
    />
  );
};