import { Modal, Form, Input, Select } from 'antd';
import { Library, Reader } from './types';
import React from 'react';

interface ReaderModalProps {
    open: boolean;
    loading?: boolean;
    editingReader?: Reader;
    libraryList?: Library[];
    readerTypes: any[];
    onOk: (values: any) => void;
    onCancel: () => void;
}

export const ReaderModal: React.FC<ReaderModalProps> = ({
    open,
    loading,
    editingReader,
    libraryList,
    readerTypes,
    onOk,
    onCancel,
}) => {
    const [form] = Form.useForm();

    return (
        <Modal
            title={editingReader ? '编辑读者' : '新增读者'}
            open={open}
            onOk={() => form.submit()}
            onCancel={onCancel}
            confirmLoading={loading}
        >
            <Form
                form={form}
                layout="vertical"
                initialValues={editingReader}
                onFinish={(values) => {
                    // 确保数据格式正确
                    const formData = {
                        name: values.name,
                        password: values.password,
                        username:values.username,
                        gender: values.gender,
                        age: values.age,
                        relax: values.relax|| null,
                        libraryId: values.libraryId,
                    };
                    onOk(formData);
                }}
            >
                <Form.Item
                    name="name"
                    label="姓名"
                    rules={[{ required: true, message: '请输入姓名' }]}
                >
                    <Input />
                </Form.Item>

                <Form.Item
                    name="password"
                    label="密码"
                    rules={[{ required: true, message: '请输入密码' }]}
                >
                    <Input />
                </Form.Item>

                <Form.Item
                    name="username"
                    label="用户名"
                    rules={[{ required: true, message: '请输入用户名' }]}
                >
                    <Input />
                </Form.Item>


                <Form.Item
                    name="gender"
                    label="性别"
                    rules={[{ required: true, message: '请输入性别' }]}
                >
                    <Input />
                </Form.Item>

                <Form.Item
                    name="age"
                    label="年龄"
                    rules={[{ required: true, message: '请输入年龄' }]}
                >
                    <Input />
                </Form.Item>

                <Form.Item
                    name="relax"
                    label="联系方式"
                >
                    <Input.TextArea />
                </Form.Item>

                <Form.Item
                    name="libraryId"
                    label="所属俱乐部"
                    rules={[{ required: true, message: '请选择所属图书馆' }]}
                >
                    <Select
                        allowClear
                        placeholder="请选择图书馆"
                    >
                        {libraryList?.map(library => (
                            <Select.Option key={library.id} value={library.id}>
                                {library.name}  {/* 使用 club 关联的 name */}
                            </Select.Option>
                        ))}
                    </Select>
                </Form.Item>

                <Form.Item
          name="terms"
          label="读者类型"
        >
          <Select
            mode="multiple"
            placeholder="请选择读者类型"
            options={readerTypes?.map(type => ({
              label: type.name,
              value: type.id
            }))}
          />
        </Form.Item>
            </Form>
        </Modal>
    );
};