import { Table, Space, Button, Popconfirm,Select } from 'antd';
import type { ColumnsType } from 'antd/es/table';
import { Reader } from './types';

import React from 'react';
interface ReaderTableProps {
  data: Reader[];
  loading?: boolean;
  readerTypes: any[];
  onEdit: (record: Reader) => void;
  onDelete: (ids: string[]) => void;
  onTypeChange: (readerId: string, termId: string, checked: boolean) => void;
}

export const ReaderTable: React.FC<ReaderTableProps> = ({
  data,
  loading,
  readerTypes,
  onEdit,
  onDelete,
  onTypeChange,
  
}) => {
  const columns: ColumnsType<Reader> = [
    {
      title: '用户名',
      dataIndex: 'username',
      key: 'username',
    },
    {
      title: '性别',
      dataIndex: 'gender',
      key: 'gender',
    },
    {
      title: '年龄',
      dataIndex: 'age',
      key: 'age',
    },
    {
        title: '联系方式',
        dataIndex: 'relax',
        key: 'relax',
    },
    {
        title: '所属图书馆',
        dataIndex: ['library', 'name'],
        key: 'libraryName',

    },
    {
      title: '创建时间',
      dataIndex: 'createdAt',
      key: 'createdAt',
      render: (date: string) => new Date(date).toLocaleString('zh-CN'),
    },

    {
      title: '读者类型',
      dataIndex: 'terms',
      render: (terms: any[], record: Reader) => (
        <Select
          mode="multiple"
          value={terms?.map(t => t.id)}
          onChange={(values) => {
            // 处理分类变更
            values.forEach(termId => {
              if (!terms?.find(t => t.id === termId)) {
                onTypeChange(record.id, termId, true);
              }
            });
            terms?.forEach(term => {
              if (!values.includes(term.id)) {
                onTypeChange(record.id, term.id, false);
              }
            });
          }}
          options={readerTypes?.map(type => ({
            label: type.name,
            value: type.id
          }))}
        />
      )
    },

    {
      title: '操作',
      key: 'action',
      render: (_, record) => (
        <Space size="middle">
          <Button type="link" onClick={() => onEdit(record)}>
            编辑
          </Button>
          <Popconfirm
            title="确定要删除吗？"
            onConfirm={() => onDelete([record.id])}
          >
            <Button type="link" danger>
              删除
            </Button>
          </Popconfirm>
        </Space>
      ),
    },
  ];

  return (
    <Table
      columns={columns}
      dataSource={data}
      loading={loading}
      rowKey="id"
    />
  );
};